@@ -314,7 +314,7 @@ class Weather:
 
         # Shift radiation by 30 minutes if resolution allows it
         if "radiation" in result.columns:
-            shift_delta = timedelta(minutes=30)
+            shift_delta = -timedelta(minutes=30)
             if shift_delta % pd.Timedelta(resolution) == timedelta(0):
                 result["radiation"] = result["radiation"].shift(1, shift_delta)
 
